@@ -3,21 +3,18 @@ Test fixtures common to more than one test point.
 """
 
 # Standard library imports
-import importlib.metadata as im
+import importlib.resources as ir
 import pathlib
-import platform
 import shutil
 import sys
 import tempfile
 import unittest
 
 # are we anaconda?
-try:
-    import conda  # noqa : F401
-except ImportError:
-    ANACONDA = False
-else:
+if 'conda' in sys.version.lower():
     ANACONDA = True
+else:
+    ANACONDA = False
 
 # are we macports?
 if sys.executable.startswith('/opt/local/Library/Frameworks/Python.framework'):
@@ -25,20 +22,6 @@ if sys.executable.startswith('/opt/local/Library/Frameworks/Python.framework'):
 else:
     MACPORTS = False
 
-# are we a linux platform that can use importlib.metadata
-if (
-    platform.system() == 'linux'
-    and platform.freedesktop_os_release()['id'] == 'opensuse-tumbleweed'
-):
-    LINUX_WITH_GOOD_IMPORTLIBMETADATA = True
-else:
-    LINUX_WITH_GOOD_IMPORTLIBMETADATA = False
-
-if ANACONDA or MACPORTS or LINUX_WITH_GOOD_IMPORTLIBMETADATA:
-    CANNOT_USE_IMPORTLIB_METADATA = False
-else:
-    CANNOT_USE_IMPORTLIB_METADATA = True
-
 # 3rd party library imports
 try:
     from osgeo import gdal  # noqa : F401
@@ -107,22 +90,9 @@ class TestJPEGCommon(TestCommon):
         Use some files supplied by scikit-image for our tests.
         """
 
-        files = im.files('scikit-image')
-
-        jpeg = next(filter(lambda x: 'retina' in x.name, files), None)
-        cls.retina = jpeg.locate()
-
-        jpeg = next(
-            filter(lambda x: 'hubble_deep_field' in x.name, files),
-            None
-        )
-        cls.hubble = jpeg.locate()
-
-        jpeg = next(
-            filter(lambda x: 'rocket' in x.name, files),
-            None
-        )
-        cls.rocket = jpeg.locate()
+        cls.retina = ir.files('skimage') / 'data' / 'retina.jpg'
+        cls.hubble = ir.files('skimage') / 'data' / 'hubble_deep_field.jpg'
+        cls.rocket = ir.files('skimage') / 'data' / 'rocket.jpg'
 
     def setUp(self):
         super().setUp()
